aboutsummaryrefslogtreecommitdiff
path: root/engines/kyra/kyra.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/kyra/kyra.h')
-rw-r--r--engines/kyra/kyra.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/kyra/kyra.h b/engines/kyra/kyra.h
index a865bf2c3b..18a4a52fe2 100644
--- a/engines/kyra/kyra.h
+++ b/engines/kyra/kyra.h
@@ -72,7 +72,7 @@ struct AudioDataStruct {
// in the future we maybe merge some flags and/or create new ones
enum kDebugLevels {
kDebugLevelScriptFuncs = 1 << 0, // prints debug output of o#_* functions
- kDebugLevelScript = 1 << 1, // prints debug output of "ScriptHelper" functions
+ kDebugLevelScript = 1 << 1, // prints debug output of "EMCInterpreter" functions
kDebugLevelSprites = 1 << 2, // prints debug output of "Sprites" functions
kDebugLevelScreen = 1 << 3, // prints debug output of "Screen" functions
kDebugLevelSound = 1 << 4, // prints debug output of "Sound" functions
@@ -175,7 +175,7 @@ protected:
TextDisplayer *_text;
StaticResource *_staticres;
TimerManager *_timer;
- ScriptHelper *_scriptInterpreter;
+ EMCInterpreter *_emc;
// config specific
virtual void registerDefaultSettings();